<?php
session_start();
include "../config.php";

require_once('../vendor/autoload.php');

use Firebase\JWT\JWT;


// Check if the user is logged in
if (!isset($_SESSION['username'])) {
    header("Location: ../login.php");
    exit();
}

$company_id = $_SESSION['company_id'];

$response = fetchUserFromAPI($company_id);
$cartItems = $response['result'];
$savedCards = fetchSavedCards($company_id);
// Dummy data
function fetchUserFromAPI($company_id)
{
    global $accessKey;
    global $secretKey;

    // Define the base URL and path for the API endpoint
    $baseUrl = "https://api.corporatetools.com";
    $path = "/shopping-cart";

    // Example parameters to include in the query (URL and ID)
    // Replace with the desired URL
    // Replace with the desired URL
    // Replace with the desired URL
    // $id = "2b918be2-c66c-4aa8-bcce-052677c1f9fa";  // Replace with the desired ID

    // Prepare the query string with URL and ID
    $content = hash('sha256', '');
    $jwtPayload = [
        "path" => $path,
        "content" => $content,
        "company_id" => $company_id,



        // Include URL in the payload
        // "id" => $id     // Include ID in the payload
    ];

    $jwtHeader = [
        "access_key" => $accessKey
    ];

    // Encode the JWT token
    $jwt = JWT::encode($jwtPayload, $secretKey, 'HS256', null, $jwtHeader);

    // Prepare the complete URL with query parameters
    $queryParams = http_build_query([
        "company_id" => $company_id,

    ]);
    $url = $baseUrl . $path . "?" . $queryParams;

    // Initialize cURL session
    $ch = curl_init($url);
    $headers = [
        "Authorization: Bearer $jwt",
        "Content-Type: application/json"
    ];
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute cURL request and close the session
    $response = curl_exec($ch);
    curl_close($ch);


    return json_decode($response, true);
}
// Fetch saved cards from the database
function fetchSavedCards($company_id)
{
    // Assuming $dbConnection is your DB connection
    global $conn;
    $query = "SELECT * FROM card_details WHERE owner_id = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $company_id);  // Bind the user_id to the query
    $stmt->execute();
    $result = $stmt->get_result();

    $cards = [];
    while ($row = $result->fetch_assoc()) {
        $cards[] = $row;
    }

    return $cards;
}


?>





<html lang="en">

<?php include 'head.php'; ?>
<link rel="stylesheet" href="jquery.toast.css">

<body>


    <?php include 'left_navbar.php'; ?>
    <div class="all-content-wrapper">
        <?php include 'Navbar.php'; ?>
        <div class="header-advance-area">
            <div class="breadcome-area">
                <div class="container-fluid">
                    <div class="row" style="margin-top:50px">
                        <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                            <div class="breadcome-list">
                                <div class="row">
                                    <div class="col-lg-6 col-md-12 col-sm-12 col-xs-6">
                                        <div class="breadcomb-wp">
                                            <div class="breadcomb-icon">
                                                <i class="icon nalika-home"></i>
                                            </div>
                                            <div class="breadcomb-ctn">
                                                <h2>Check out</h2>
                                                <p>Welcome, <span class="bread-ntd"><strong><?php echo strtoupper($_SESSION['username'])  ?></strong></span></p>
                                            </div>
                                        </div>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="product-cart-area mg-b-30">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                        <div class="product-cart-inner">
                            <div id="example-basic">
                                <h3 style="color: white;">Confirm Order</h3>



                                <section>
                                    <h3 class="product-cart-dn">Shopping</h3>
                                    <div class="product-list-cart">
                                        <div class="product-status-wrap border-pdt-ct">
                                            <table>
                                                <tr>

                                                    <th>Product Title</th>

                                                    <th>Price</th>
                                                    <th>Action</th>
                                                </tr>

                                                <tr>

                                                    <?php
                                                    $total = 0;
                                                    if (!empty($cartItems)) {
                                                        foreach ($cartItems as $item) {
                                                            $cartIds[] = $item['id'];
                                                            echo '<tr>';
                                                            echo '<td>';
                                                            echo '<h3>' . htmlspecialchars($item['title']) . '</h3>';

                                                            echo '</td>';
                                                            echo '<td>$' . htmlspecialchars($item['total']) . '</td>'; // You can replace $18 with the actual price of the item if it's stored in the cart
                                                            echo '<td>';
                                                            echo '<a href="remove_cart_item.php?id=' . $item['id'] . '" data-toggle="tooltip" title="Trash" class="pd-setting-ed">';
                                                            echo '<i class="fa fa-trash-o" style="color:#8B0000; font-size:20px;" aria-hidden="true"></i>';
                                                            echo '</a>';
                                                            echo '</td>';
                                                            echo '</tr>';
                                                            $total += $item['total'];
                                                        }
                                                    } else {
                                                        echo '<tr><td colspan="3">Cart is empty.</td></tr>';
                                                    }
                                                    ?>
                                                <tr>
                                                    <td style="text-align:right; font-weight:bold; font-size:20px;">Total:</td>
                                                    <td style="font-size:20px;"><?php echo '$' . number_format($total, 2); ?></td>



                                                </tr>

                                                <tr >
                                                    <td style="font-weight:bold;">
                                                        <div style="display: flex;  align-items:center; margin-left: 15%; width:100%;margin-top:20px;">
                                                            <form action="shopping_checkout.php" method="POST" style="display: flex;  align-items: center; flex-direction: column; width:100%;">
                                                                <h3>Select Payment Method</h3>
                                                                <div class="saved-cards" style="margin-top:10px;margin-bottom:10px; ">
                                                                    <?php
                                                                    if (!empty($savedCards)) {
                                                                        echo '<ul style="list-style-type: none; padding: 10px; ">'; // Remove default list style
                                                                        $index = 0;
                                                                        foreach ($savedCards as $card) {
                                                                            echo '<li style="margin-bottom: 10px; border:0.1px solid grey; padding:10px 30px;">'; // Each card is in a list item
                                                                            $checked = $index === 0 ? 'checked' : ''; 
                                                                            echo '<input type="radio" style="font-size:30px;width: 15px; height: 15px;" required id="card_' . $card['card_id'] . '" name="payment_method" value="' . $card['card_id'] . '" ' . $checked . '>';
                                                                            if (strtolower($card['card_brand']) === 'visa') {
                                                                                echo '<img src="img/visa.png" style="margin-top: 2px; margin-left:7px; height: 40px;width:40px;  ">';
                                                                            } elseif (strtolower($card['card_brand']) === 'mastercard') {
                                                                                echo '<img src="img/m_card.png" style="margin-top: 2px;margin-left:7px; height: 40px;width:40px;">';
                                                                            }
                                                                            echo '<label style="margin-left: 5px;font-size: 20px;" for="card_' . $card['card_id'] . '">**** **** **** ' . $card['last4'] . ' (' . htmlspecialchars($card['first_name']) . ')</label>';
                                                                            echo '</li>';
                                                                        }
                                                                        echo '</ul>';
                                                                    } else {
                                                                        echo '<p>No saved cards found. Please add a card.</p>';
                                                                    }
                                                                    ?>
                                                                </div>
                                                                <input type="hidden" name="cart_ids" value="<?php echo implode(',', $cartIds); ?>">
                                                                <div>
                                                                    <button type="submit" class="btn btn-success">Confirm Payment</button>
                                                                </div>
                                                            </form>
                                                        </div>
                                                    </td>
                                                </tr>






                                            </table>
                                        </div>
                                    </div>
                                </section>

                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </div>








    <?php include 'jquery.php'; ?>




    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="jquery.toast.js"></script>


    <?php
    // Display Toast on Page Load Based on Session Success/Error Messages
    if (isset($_SESSION['success_cart']) || isset($_SESSION['error_cart'])):
    ?>
        <script>
            $(document).ready(function() {
                // Ensure a slight delay for processing the cart operation
                setTimeout(function() {
                    <?php if (isset($_SESSION['success_cart'])): ?>
                        $.toast({
                            heading: 'Success',
                            text: '<?php echo $_SESSION['success_cart']; ?>',
                            icon: 'success',
                            position: 'top-right',
                            hideAfter: 5000,
                        });
                        <?php unset($_SESSION['success_cart']); ?>
                    <?php elseif (isset($_SESSION['error_cart'])): ?>
                        $.toast({
                            heading: 'Error',
                            text: '<?php echo $_SESSION['error_cart']; ?>',
                            icon: 'error',
                            position: 'top-right',
                            hideAfter: 5000,
                        });
                        <?php unset($_SESSION['error_cart']); ?>
                    <?php endif; ?>
                }, 1000); // Adding a 1-second delay for better UX
            });
        </script>
    <?php endif; ?>

</body>

</html>