<?php
require_once('../config.php');
require_once('../vendor/autoload.php');
session_start();
if (!isset($_SESSION['username'])) {
    header("Location: ../login.php");
    exit();
}

use Firebase\JWT\JWT;



$product_id = isset($_GET['id']) ? $_GET['id'] : null;

if (!isset($_SESSION['cart'])) {
    $_SESSION['cart'] = [];
}

// Add product to the session cart (if it's not already added)
if (!in_array($product_id, $_SESSION['cart'])) {
    $_SESSION['cart'][] = $product_id; // You can store more details like product name, price, etc. here if needed
    $_SESSION['cart_count'] = count($_SESSION['cart']); // Store count of items
    $_SESSION['success_message'] = "Product added to cart!";
}





$company_id = $_SESSION['company_id'];
$jurisdiction = trim($_SESSION['home_state']);

$response = fetchUserFromAPI($product_id, $company_id, $jurisdiction);


$product_option_id = $response['result'][0]['id'];
$_SESSION['product_option_id'] = $product_option_id;


$shopping_cart = addToShoppingCart($company_id,$product_id,$product_option_id);
$cartResponse = json_decode($shopping_cart, true);

// Check if success is true
if (isset($cartResponse['success']) && $cartResponse['success'] === true) {
    // Set session message
    $_SESSION['success'] = "Product added to the shopping cart successfully.";

    // Redirect to filing_products.php
    header("Location: filing_products.php");
    exit();
} else {
    // Handle failure case (optional)
    $_SESSION['error'] = "Failed to add the product to the shopping cart.";
    header("Location: filing_products.php");
    exit();
}



function fetchUserFromAPI($product_id, $company_id, $jurisdiction)
{
    global $accessKey;
    global $secretKey;

    // Define the base URL and path for the API endpoint
    $baseUrl = "https://api.corporatetools.com";
    $path = "/filing-methods";

    // Example parameters to include in the query (URL and ID)
    $company_id = $company_id;
    $filing_product_id = $product_id;
    $jurisdiction = $jurisdiction;  // Replace with the desired URL
    // Replace with the desired URL
    // Replace with the desired URL
    // $id = "2b918be2-c66c-4aa8-bcce-052677c1f9fa";  // Replace with the desired ID

    // Prepare the query string with URL and ID
    $content = hash('sha256', '');
    $jwtPayload = [
        "path" => $path,
        "content" => $content,
        "company_id" => $company_id,
        "filing_product_id" => $filing_product_id,
        "jurisdiction" => $jurisdiction,


        // Include URL in the payload
        // "id" => $id     // Include ID in the payload
    ];

    $jwtHeader = [
        "access_key" => $accessKey
    ];

    // Encode the JWT token
    $jwt = JWT::encode($jwtPayload, $secretKey, 'HS256', null, $jwtHeader);

    // Prepare the complete URL with query parameters
    $queryParams = http_build_query([
        "company_id" => $company_id,
        "filing_product_id" => $filing_product_id,
        "jurisdiction" => $jurisdiction,
    ]);
    
    $url = $baseUrl . $path . "?" . $queryParams;

    // Initialize cURL session
    $ch = curl_init($url);
    $headers = [
        "Authorization: Bearer $jwt",
        "Content-Type: application/json"
    ];
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute cURL request and close the session
    $response = curl_exec($ch);
    curl_close($ch);

    return json_decode($response, true);
}
function addToShoppingCart($company_id, $product_id, $product_option_id)
{
    global $accessKey;
    global $secretKey;

    $baseUrl = "https://api.corporatetools.com";  // Base URL for the API
    $path = "/shopping-cart";  // Endpoint for shopping cart

    // Prepare the data to be sent in the request
    $payload = [
        "company_id" => $company_id,
        "product_id" =>$product_id,
        "product_option_id" =>$product_option_id,
        "quantity" => 1,

    ];

    // Generate the content hash and JWT token
    $queryString = "";  // Additional parameters if needed
    $bodyContent = json_encode($payload);  // JSON encode the data
    $content = hash('sha256', $queryString . $bodyContent);  // Hash the content for security

    // Prepare JWT payload and headers
    $jwtPayload = [
        "path" => $path,
        "content" => $content
    ];
    $jwtHeader = [
        "access_key" => $accessKey
    ];
    $jwt = JWT::encode($jwtPayload, $secretKey, 'HS256', null, $jwtHeader);

    // Setup cURL
    $url = $baseUrl . $path;  // Full URL to make the request
    $ch = curl_init($url);
    $headers = [
        "Authorization: Bearer $jwt",
        "Content-Type: application/json"
    ];

    // cURL options for POST request
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $bodyContent);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute the cURL request
    $response = curl_exec($ch);
    curl_close($ch);  // Close cURL session
    return $response;
}
