<?php
session_start();
include "../config.php";


use Firebase\JWT\JWT;

require_once('../vendor/autoload.php');

// Check if the user is logged in
if (!isset($_SESSION['username'])) {
    header("Location: ../login.php");
    exit();
}
$filing_name = isset($_GET['filing_name']) ? $_GET['filing_name'] : '';


$filing_response = filingAPI($filing_name);



function filingAPI($filing_name) {
    global $accessKey;
    global $secretKey;

    $baseUrl = "https://api.corporatetools.com";
    $path = "/filing-products";

    $url = "www.northwestregisteredagent.com";  // Replace with the desired URL

    $content = hash('sha256', '');
    $jwtPayload = [
        "path" => $path,
        "content" => $content,
        "url" => $url,
    ];

    $jwtHeader = [
        "access_key" => $accessKey
    ];

    // Encode the JWT token
    $jwt = JWT::encode($jwtPayload, $secretKey, 'HS256', null, $jwtHeader);

    // Prepare the complete URL
    $url = $baseUrl . $path . "?url=" . urlencode($url);

    // Initialize cURL session
    $ch = curl_init($url);
    $headers = [
        "Authorization: Bearer $jwt",
        "Content-Type: application/json"
    ];
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute cURL request
    $response = curl_exec($ch);

    if (curl_errno($ch)) {
        echo 'Curl error: ' . curl_error($ch);
        curl_close($ch);
        return [];
    }

    curl_close($ch);

    // Decode JSON response
    $decodedResponse = json_decode($response, true);
    if (!isset($decodedResponse['result']) || !is_array($decodedResponse['result'])) {
        echo "Error: API response does not contain a valid 'result' array.";
        return [];
    }

    $filing_name = $filing_name; // Replace with the desired category

    // Filter the result array
    $filteredResponse = array_filter($decodedResponse['result'], function ($item) use ($filing_name) {
        return isset($item['filing_name']) && $item['filing_name'] === $filing_name;
    });

    return $filteredResponse;
    // Debug the response structure

}







?>



<!DOCTYPE html>
<html lang="en">

<?php include 'head.php'; ?>
<link rel="stylesheet" href="jquery.toast.css">

<body>


    <?php include 'left_navbar.php'; ?>
    <div class="all-content-wrapper">
        <?php include 'Navbar.php'; ?>

        <div class="header-advance-area">
            <div class="breadcome-area">
                <div class="container-fluid">
                    <div class="row" style="margin-top:50px">
                        <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                            <div class="breadcome-list">
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-6">
                                        <div class="breadcomb-wp">
                                            <div class="breadcomb-icon">
                                                <i class="icon nalika-home"></i>
                                            </div>
                                            <div class="breadcomb-ctn">
                                                <h2>Product List</h2>
                                                <p>Welcome, <span class="bread-ntd"><strong><?php echo strtoupper($_SESSION['username'])  ?></strong></span></p>
                                            </div>
                                        </div>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>



        <div class="product-status mg-b-30">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                        <div class="product-status-wrap">
                            <h4>Buy Products</h4>

                            <table>
                                <tr>
                                    <th scope="col">Name</th>
                                    <th scope="col">Category</th>
                                    <th scope="col">Price</th>
                                    <th scope="col"> Add to Cart</th>




                                </tr>
                                <tr>

                                <tr>
                                <tr>
                                    <?php
                                    // Assuming $response contains an array of product items directly
                                    if (is_array($filing_response)) {
                                        foreach ($filing_response as $item) {
                                            // $item will represent each product in the array
                                    ?>
                                <tr>
                                    <td><?php echo $item['name'] ?? 'No Name'; ?><br>

                                    </td>
                                    <td><?php echo $item['filing_name'] ?? 'No Category'; ?></td>
                                    <td><?php echo "$" . ($item['price'] ?? 'No Price'); ?></td>


                                    <td>
                                        <a class="btn btn-success add-to-cart-" onclick="addToCart()" href="filing_method_testing.php?id=<?php echo $item['id']; ?>">



                                            <i class="fa-solid fa-cart-shopping" style="color: white;"></i>
                                        </a>
                                    </td>


                                </tr>
                        <?php
                                        }
                                    } else {
                                        echo "No products found.";
                                    }
                        ?>



                        </tr>
                        
                            </table>

                        </div>
                    </div>
                </div>
            </div>
        </div>


    </div>










    <?php include 'jquery.php'; ?>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="jquery.toast.js"></script>


    <?php
    // Display Toast on Page Load Based on Session Success/Error Messages
    if (isset($_SESSION['success']) || isset($_SESSION['error'])):
    ?>
        <script>
            $(document).ready(function() {
                // Ensure a slight delay for processing the cart operation
                setTimeout(function() {
                    <?php if (isset($_SESSION['success'])): ?>
                        $.toast({
                            heading: 'Success',
                            text: '<?php echo $_SESSION['success']; ?>',
                            icon: 'success',
                            position: 'top-right',
                            hideAfter: 5000,
                        });
                        <?php unset($_SESSION['success']); ?>
                    <?php elseif (isset($_SESSION['error'])): ?>
                        $.toast({
                            heading: 'Error',
                            text: '<?php echo $_SESSION['error']; ?>',
                            icon: 'error',
                            position: 'top-right',
                            hideAfter: 5000,
                        });
                        <?php unset($_SESSION['error']); ?>
                    <?php endif; ?>
                }, 1000); // Adding a 1-second delay for better UX
            });
        </script>
    <?php endif; ?>





</body>

</html>