<?php
session_start();
include "../config.php";


use Firebase\JWT\JWT;

require_once('../vendor/autoload.php');

// Check if the user is logged in
if (!isset($_SESSION['username'])) {
    header("Location: ../login.php");
    exit();
}

$filing_name = isset($_GET['filing_name']) ? $_GET['filing_name'] : '';

$response = fetchUserFromAPI($filing_name);


function fetchUserFromAPI($filing_name)
{
    global $accessKey;
    global $secretKey;

    $baseUrl = "https://api.corporatetools.com";
    $path = "/filing-products";

    $url = "www.northwestregisteredagent.com";  // Replace with the desired URL

    $content = hash('sha256', '');
    $jwtPayload = [
        "path" => $path,
        "content" => $content,
        "url" => $url,
    ];

    $jwtHeader = [
        "access_key" => $accessKey
    ];

    // Encode the JWT token
    $jwt = JWT::encode($jwtPayload, $secretKey, 'HS256', null, $jwtHeader);

    // Prepare the complete URL
    $url = $baseUrl . $path . "?url=" . urlencode($url);

    // Initialize cURL session
    $ch = curl_init($url);
    $headers = [
        "Authorization: Bearer $jwt",
        "Content-Type: application/json"
    ];
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute cURL request
    $response = curl_exec($ch);

    if (curl_errno($ch)) {
        echo 'Curl error: ' . curl_error($ch);
        curl_close($ch);
        return [];
    }

    curl_close($ch);

    // Decode JSON response
    $decodedResponse = json_decode($response, true);

    // Debug the response structure
    if (!isset($decodedResponse['result']) || !is_array($decodedResponse['result'])) {
        echo "Error: API response does not contain a valid 'result' array.";
        return [];
    }

    $filing_name = $filing_name; // Replace with the desired category

    // Filter the result array
    $filteredResponse = array_filter($decodedResponse['result'], function ($item) use ($filing_name) {
        return isset($item['filing_name']) && $item['filing_name'] === $filing_name;
    });

    return $filteredResponse;
}






?>



<!DOCTYPE html>
<html lang="en">

<?php include 'head.php'; ?>

<body>


    <?php include 'left_navbar.php'; ?>
    <div class="all-content-wrapper">
        <?php include 'Navbar.php'; ?>
        <div class="header-advance-area">
            <div class="breadcome-area">
                <div class="container-fluid">
                    <div class="row" style="margin-top:50px">
                        <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                            <div class="breadcome-list">
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-6">
                                        <div class="breadcomb-wp">
                                            <div class="breadcomb-icon">
                                                <i class="icon nalika-home"></i>
                                            </div>
                                            <div class="breadcomb-ctn">
                                                <h2>Product List</h2>
                                                <p>Welcome, <span class="bread-ntd"><strong><?php echo strtoupper($_SESSION['username'])  ?></strong></span></p>
                                            </div>
                                        </div>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="product-status mg-b-30">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                        <div class="product-status-wrap">
                            <h4>Buy Products</h4>

                            <table>
                                <tr>
                                    <th scope="col">Name</th>
                                    <th scope="col">Category</th>
                                    <th scope="col">Price</th>
                                    <th scope="col"> Add to Cart</th>




                                </tr>
                                <tr>

                                <tr>
                                <tr>
                                    <?php
                                    // Assuming $response contains an array of product items directly
                                    if (is_array($response)) {
                                        foreach ($response as $item) {
                                            // $item will represent each product in the array
                                    ?>
                                <tr>
                                    <td><?php echo $item['name'] ?? 'No Name'; ?><br>
                                        <small><?php echo $item['description'] ?? ''; ?></small>
                                    </td>
                                    <td><?php echo $item['category'] ?? 'No Category'; ?></td>
                                    <td><?php echo "$" . ($item['price'] ?? 'No Price'); ?></td>

                                    <td>
                                        <button class="btn btn-success add-to-cart-btn"
                                            data-id="<?php echo $item['id']; ?>"
                                            data-name="<?php echo $item['name']; ?>"
                                            data-price="<?php echo $item['price']; ?>">
                                            <i class="fa-solid fa-cart-shopping" style="color: white;"></i>
                                        </button>
                                    </td>


                                </tr>
                        <?php
                                        }
                                    } else {
                                        echo "No products found.";
                                    }
                        ?>



                        </tr>
                            </table>

                        </div>
                    </div>
                </div>
            </div>
        </div>


    </div>


    







    <?php include 'jquery.php'; ?>


    <?php include 'cart_js.php'; ?>
   


</script>


</body>

</html>