<?php
include "../config.php";

require_once('../vendor/autoload.php');

use Firebase\JWT\JWT;

session_start();

$itemId = isset($_GET['id']) ? $_GET['id'] : null; // Get the item ID from the URL query string
$company_id = $_SESSION['company_id'];

$response = deleteUserFromAPI([$itemId], $company_id); // Pass itemId as an array
$decodedResponse = json_decode($response);

// Check if the response indicates success
if ($decodedResponse && $decodedResponse->success == true) {
    // Store the success message in session
    $_SESSION['message'] = "Item deleted successfully";

    // Redirect to the 'add_to_cart.php' page
    header("Location: add_to_cart.php");
    exit(); // Make sure no further code is executed after the redirect
} else {
    // Handle failure if necessary (e.g., store an error message in session)
    $_SESSION['message'] = "Failed to delete the item.";
    header("Location: add_to_cart.php");
    exit();
}


// Dummy data
function deleteUserFromAPI($itemIds, $company_id)
{
    global $accessKey;
    global $secretKey;

    // Define the base URL and path for the API endpoint
    $baseUrl = "https://api.corporatetools.com";
    $path = "/shopping-cart";

    // Prepare the payload for the JWT
    $content = hash('sha256', '');
    $jwtPayload = [
        "path" => $path,
        "content" => $content,
        "company_id" => $company_id,
        "item_ids" => $itemIds // Pass item_ids as an array here
    ];

    $jwtHeader = [
        "access_key" => $accessKey
    ];

    // Encode the JWT token
    $jwt = JWT::encode($jwtPayload, $secretKey, 'HS256', null, $jwtHeader);

    // Prepare the full URL without item_ids in query
    $url = $baseUrl . $path;

    // Initialize cURL session
    $ch = curl_init($url);

    // Set cURL options for DELETE request
    $headers = [
        "Authorization: Bearer $jwt",
        "Content-Type: application/json"
    ];

    // Create the request body with item_ids as an array
    $data = json_encode([
        "company_id" => $company_id,
        "item_ids" => $itemIds
    ]);

    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE"); // Specify DELETE method
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data); // Send the data in the body of the request

    // Execute cURL request and close the session
    $response = curl_exec($ch);
    curl_close($ch);

    return $response;
}
