<?php
// Start the session
session_start();

include "config.php";
include 'auth-head.php';
include 'function.php';
// Include PHPMailer class


require 'vendor/autoload.php';

// Check if the form is submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the form data
    $email = $_POST['email'];

    // Basic validation
    if (empty($email)) {
        $_SESSION['error'] = "Please enter your email address!";
        header("Location: forget_password.php");
        exit;
    }

    // Prepare and bind the query to check if the email exists in the database
    $stmt = $conn->prepare("SELECT id, email, name FROM companies WHERE email = ?");
    $stmt->bind_param("s", $email);  // "s" stands for string type
    $stmt->execute();
    $stmt->store_result();

    // Check if the email exists
    if ($stmt->num_rows > 0) {

        $stmt->bind_result($id, $email, $name);
        $stmt->fetch();

        // Generate a random 50-byte token
        $token = bin2hex(random_bytes(50));

        // Set the token expiry time (1 day)
        $expiry_time = date('Y-m-d H:i:s', strtotime('+1 day'));

        // Store the token and expiry time in the database (in a new table for password resets)
        $stmt = $conn->prepare("INSERT INTO password_resets (email, token, expiry_time) VALUES (?, ?, ?)");
        $stmt->bind_param("sss", $email, $token, $expiry_time);
        if ($stmt->execute()) {
            // Prepare reset password link
            $reset_link = "$domain/reset_password.php?token=" . $token;
            $subject = "Password Reset Request | Economic Masonry";
            $body = "
            <div style='font-family: Arial, sans-serif; color: #333; line-height: 1.6;'>
                <h2 style='color: #4CAF50;'>Password Reset Request</h2>
                <p>Dear <strong> $name</strong>,</p>
                <p>We received a request to reset your password for your Economic Masonry account.</p>
                <p>To reset your password, please click the link below:</p>
                <p><a href='$reset_link' style='background-color: #4CAF50; color: white; padding: 10px 20px; text-decoration: none; border-radius: 5px;'>Reset Password</a></p>
                <p>If you have any questions, feel free to contact our support team.</p>
                <p>Best regards,</p>
                <p><strong>The Economic Masonry Team</strong></p>
            </div>
        ";
            // Send the reset email
            if (sendemail($email, $subject, $body)) {
                $_SESSION['success'] = "A password reset link has been sent to your email address.";
                header("Location: forget_password.php");
                exit;
            } else {
                $_SESSION['error'] = "Failed to send the reset link. Please try again.";
                header("Location: forget_password.php");
                exit;
            }
        } else {
            $_SESSION['error'] = "Error generating reset token. Please try again.";
            header("Location: forget_password.php");
            exit;
        }
    } else {
        $_SESSION['error'] = "No account found with that email address.";
        header("Location: forget_password.php");
        exit;
    }

    $stmt->close();
}

// Close the connection
$conn->close();

// Function to send the reset email

?>

<!DOCTYPE html>
<html lang="en">

<head>
    <link rel="stylesheet" href="assests/css/login.css">
</head>

<body>


    <div class="container d-flex justify-content-center align-items-center min-vh-100">
        <div class="card p-4 shadow-lg" style="max-width: 400px; width: 100%;">

            <div class="text-center mb-1">
                <img src="assests/img/logo.webp" alt="Logo" class="img-fluid" style="max-width: 100px;">
                <h3 class="mt-3">Economic Masonry</h3>
            </div>

            <!-- Error Message Display -->
            <div class="text-center mb-1 error-msg">
                <?php
                if (isset($_SESSION['error'])) {
                    echo "<h6 style='color: red;'>" . $_SESSION['error'] . "</h6>";
                    unset($_SESSION['error']);
                }
                ?>
            </div>

            <!-- Success Message Display -->
            <div class="text-center mb-1 success-msg">
                <?php
                if (isset($_SESSION['success'])) {
                    echo "<h6 style='color: green;'>" . $_SESSION['success'] . "</h6>";
                    unset($_SESSION['success']);
                }
                ?>
            </div>

            <h4 class="text-center mb-3">Forget Password</h4>

            <!-- forget Password Form -->
            <form method="POST" action="forget_password.php">
                <div class="form-group">
                    <label for="exampleInputEmail1">Email address</label>
                    <input type="email" name="email" class="form-control" required id="exampleInputEmail1" placeholder="Enter your email">
                </div>
                <div class="d-flex justify-content-center">
                    <button type="submit" class="btn btn-success w-50">Send Reset Link</button>
                </div>
            </form>

            <!-- Links to Login and Register -->
            <div class="text-center mt-3">
                <a href="login.php" class="text-muted">Back to Login</a>
            </div>
            <div class="text-center mt-2">
                <a href="register.php" class="text-muted">Create an Account?</a>
            </div>

        </div>
    </div>
</body>

</html>