<?php
require_once 'vendor/autoload.php';

use Firebase\JWT\JWT;
use PHPMailer\PHPMailer\PHPMailer;

session_start();
include "config.php";
include "function.php";





if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];
    $password = $_POST['password'];
    $name = $_POST['name'];
    $company_name = $_POST['company_name'];
    $home_state = $_POST['home_states'];
    $business_type = $_POST['business_type'];
   


    if (empty($email) || empty($password) || empty($company_name) || empty($name) || empty($home_state) || empty($business_type)) {
        $_SESSION['error'] = "All fields are required. Please fill in the form correctly.";
        header("Location: register.php");
        exit;
    }

    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $_SESSION['error'] = "Invalid email format.";
        header("Location: register.php");
        exit;
    }

    $stmt = $conn->prepare("SELECT email FROM companies WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        $_SESSION['error'] = "The email address is already registered.";
        $stmt->close();
        header("Location: register.php");
        exit;
    }

    if (!preg_match("/^(?=.*[A-Z])(?=.*\d)(?=.*[@$!%*?&])[A-Za-z\d@$!%*?&]{8,}$/", $password)) {
        $_SESSION['error'] = "Password must meet complexity requirements.";
        header("Location: register.php");
        exit;
    }

    $hashed_password = password_hash($password, PASSWORD_DEFAULT);

    $stmt = $conn->prepare("INSERT INTO companies (email, password, company_name, name, home_state, business_type) VALUES (?, ?, ?, ?, ?,  ?)");
    $stmt->bind_param("ssssss", $email, $hashed_password, $company_name, $name, $home_state, $business_type);
    $subject = "Welcome to Economic Masonry | Account Created Successfully!";
    $body = "
        <div style='font-family: Arial, sans-serif; color: #333; line-height: 1.6;'>
            <h2 style='color: #4CAF50;'>Welcome to Economic Masonry!</h2>
            <p>Dear <strong>$name</strong>,</p>
            <p>We are excited to inform you that your account has been successfully created. Here are your login details:</p>
            <table style='border-collapse: collapse; width: 100%; max-width: 500px; margin: 10px 0;'>
                <tr>
                    <td style='padding: 8px; border: 1px solid #ddd;'>Email:</td>
                    <td style='padding: 8px; border: 1px solid #ddd;'>$email</td>
                </tr>
                <tr>
                    <td style='padding: 8px; border: 1px solid #ddd;'>Password:</td>
                    <td style='padding: 8px; border: 1px solid #ddd;'>$password</td>
                </tr>
            </table>  
            <p>Best regards,</p>
            <p><strong>The Economic Masonry Team</strong></p>
        </div>
    ";
    if ($stmt->execute() && sendemail($email,$subject,$body)) {
        
        $_SESSION['success'] = "Registeration Successful";
        header("Location: register.php");


        $stmt->close();
    } else {

        error_log("SQL Error: " . $stmt->error);
        $stmt->close();
    }
    $company_id = createCompany($company_name, $business_type, $home_state);

    if ($company_id) {
        $stmt = $conn->prepare("UPDATE companies SET company_id = ? WHERE email = ?");
        $stmt->bind_param("ss", $company_id, $email);
        if ($stmt->execute()) {
            $_SESSION['success'] = "Registration successfull! Your company has been registered.";
        } else {
            echo "Error updating company ID: " . $stmt->error;
            $_SESSION['error'] = "Error: " . $stmt->error;
        }

        header("Location:register.php");
        $stmt->close();
        $conn->close();

        exit;
    }
}



// Function to create a company via API
function createCompany($name, $entity_type, $home_state)
{
    global   $accessKey;
    global $secretKey;

    $baseUrl = "https://api.corporatetools.com";
    $path = "/companies";

    // Company data
    $companies = [
        [
            "name" => $name, // Company name (ensure $name is defined before this block)
            "entity_type" => $entity_type, // Entity type (ensure $entity_type is defined)
            "home_state" => $home_state, 
        ],
    ];

    // Payload
    $payload = [
        "companies" => $companies,
        "duplicate_name_allowed" => true
    ];

    // Generate SHA-256 hash for content
    $queryString = ""; // No query string in this example
    $bodyContent = json_encode($payload); // JSON encode the payload
    $content = hash('sha256', $queryString . $bodyContent); // Generate hash of query string + body

    // Build JWT
    $jwtPayload = [
        "path" => $path,
        "content" => $content
    ];
    $jwtHeader = [
        "access_key" => $accessKey
    ];
    $jwt = \Firebase\JWT\JWT::encode($jwtPayload, $secretKey, 'HS256', null, $jwtHeader); // Use Firebase JWT library

    // Initialize cURL
    $url = $baseUrl . $path;
    $ch = curl_init($url);
    $headers = [
        "Authorization: Bearer $jwt", // Add Bearer token
        "Content-Type: application/json" // Indicate JSON content type
    ];
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $bodyContent);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    // Execute cURL request
    $response = curl_exec($ch);
    $response_data = json_decode($response, true);
    curl_close($ch);

    // Print or return the response


    return $response_data['result'][0]['id'] ?? null;
}
