<?php
// Start the session
session_start();

include "config.php";  
include 'auth-head.php';

require 'vendor/autoload.php';  

// Check if the token is provided
// if (!isset($_GET['token']) || empty($_GET['token'])) {
//     $_SESSION['error'] = "Invalid token!";
//     header("Location: forget_password.php");
//     exit;
// }

$token = $_GET['token'];


$stmt = $conn->prepare("SELECT email, token, expiry_time FROM password_resets WHERE token = ?");
$stmt->bind_param("s", $token);
$stmt->execute();
$stmt->store_result();

// Check if the token exists and is not expired
if ($stmt->num_rows > 0) {
    $stmt->bind_result($email, $db_token, $expiry_time);
    $stmt->fetch();

    // Check if the token has expired
    if (strtotime($expiry_time) < time()) {
        $_SESSION['error'] = "The password reset link has expired!";
        header("Location: forget_password.php");
        exit;
    }

    if ($_SERVER['REQUEST_METHOD'] == 'POST') {
        // Get the new password and confirm password
        $new_password = $_POST['new_password'];
        $confirm_password = $_POST['confirm_password'];

        // Basic validation
        if (empty($new_password) || empty($confirm_password)) {
            $_SESSION['error'] = "Please enter and confirm your new password!";
            header("Location: reset_password.php?token=$token");
            exit;
        }

        // Check if the passwords match
        if ($new_password !== $confirm_password) {
            $_SESSION['error'] = "Passwords do not match!";
            header("Location: reset_password.php?token=$token");
            exit;
        }

        // Hash the new password
        $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);

        // Update the password in the database
        $stmt = $conn->prepare("UPDATE companies SET password = ? WHERE email = ?");
        $stmt->bind_param("ss", $hashed_password, $email);
        if ($stmt->execute()) {
            // Delete the token from the password_resets table as it has been used
            $stmt = $conn->prepare("DELETE FROM password_resets WHERE token = ?");
            $stmt->bind_param("s", $token);
            $stmt->execute();

            $_SESSION['success'] = "Your password has been successfully reset. You can now log in.";
            header("Location: reset_password.php");
            exit;
        } else {
            $_SESSION['error'] = "Failed to reset the password. Please try again.";
            header("Location: reset_password.php?token=$token");
            exit;
        }
    }

    $stmt->close();
} else {
    // $_SESSION['error'] = "Invalid or expired token!";
    header("Location: forget_password.php");
    exit;
}

// Close the connection
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <link rel="stylesheet" href="assests/css/login.css">
</head>
<body>

<div class="container d-flex justify-content-center align-items-center min-vh-100">
    <div class="card p-4 shadow-lg" style="max-width: 400px; width: 100%;">

        <div class="text-center mb-1">
            <img src="assests/img/logo.webp" alt="Logo" class="img-fluid" style="max-width: 100px;">
            <h3 class="mt-3">Economic Masonry</h3>
        </div>

        <!-- Error Message Display -->
        <div class="text-center mb-2 error-msg">
            <?php 
            if (isset($_SESSION['error'])) {
                echo "<h6 style='color: red;'>" . $_SESSION['error'] . "</h6>";
                unset($_SESSION['error']);
            }
            ?>
        </div>

        <!-- Success Message Display -->
        <div class="text-center mb-2 success-msg">
            <?php 
            if (isset($_SESSION['success'])) {
                echo "<h6 style='color: green;'>" . $_SESSION['success'] . "</h6>";
                unset($_SESSION['success']);
            }
            ?>
        </div>

        <h4 class="text-center mb-3">Reset Password</h4>

        <!-- Reset Password Form -->
        <form method="POST" action="reset_password.php?token=<?php echo $token; ?>">
            <div class="form-group">
                <label for="newPassword">New Password</label>
                <input type="password" name="new_password" class="form-control" required id="newPassword" placeholder="Enter new password">
            </div>
            <div class="form-group">
                <label for="confirmPassword">Confirm Password</label>
                <input type="password" name="confirm_password" class="form-control" required id="confirmPassword" placeholder="Confirm new password">
            </div>
            <div class="d-flex justify-content-center">
                <button type="submit" class="btn btn-success w-50">Reset Password</button>
            </div>
        </form>

        <!-- Links to Login and Register -->
        <div class="text-center mt-3">
            <a href="login.php" class="text-muted">Back to Login</a>
        </div>
        <div class="text-center mt-2">
            <a href="register.php" class="text-muted">Create an Account?</a>
        </div>

    </div>
</div>

</body>
</html>
